@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2021 Free Software Foundation, Inc.
+# Copyright (C) 2012-2022 Free Software Foundation, Inc.
 #
 # This file is part of GDB.
 #
@@ -19,4 +19,4 @@
 development=true
 
 # Indicate whether this is a release branch.
-experimental=false
+experimental=true
