@@ -2,7 +2,7 @@
 
 # split_x86_64.sh -- test -fstack-split for x86_64
 
-# Copyright (C) 2009-2018 Free Software Foundation, Inc.
+# Copyright (C) 2009-2022 Free Software Foundation, Inc.
 # Written by Ian Lance Taylor <iant@google.com>.
 
 # This file is part of gold.
@@ -39,16 +39,16 @@ nomatch()
 }
 
 match 'cmp.*%fs:[^,]*,%rsp' split_x86_64_1.stdout
-match 'callq.*__morestack>?$' split_x86_64_1.stdout
+match 'call.*__morestack>?$' split_x86_64_1.stdout
 match 'lea.*-0x200\(%rsp\),' split_x86_64_1.stdout
 
 match 'stc' split_x86_64_2.stdout
-match 'callq.*__morestack_non_split>?$' split_x86_64_2.stdout
-nomatch 'callq.*__morestack>?$' split_x86_64_2.stdout
-match 'lea.*-0x4200\(%rsp\),' split_x86_64_2.stdout
+match 'call.*__morestack_non_split>?$' split_x86_64_2.stdout
+nomatch 'call.*__morestack>?$' split_x86_64_2.stdout
+match 'lea.*-0x100200\(%rsp\),' split_x86_64_2.stdout
 
 match 'failed to match' split_x86_64_3.stdout
 
-match 'callq.*__morestack>?$' split_x86_64_4.stdout
+match 'call.*__morestack>?$' split_x86_64_4.stdout
 
 match 'cannot mix' split_x86_64_r.stdout
