@@ -1,5 +1,5 @@
 /* Demangler for the Rust programming language
-   Copyright (C) 2016-2021 Free Software Foundation, Inc.
+   Copyright (C) 2016-2022 Free Software Foundation, Inc.
    Written by David Tolnay (dtolnay@gmail.com).
    Rewritten by Eduard-Mihai Burtescu (eddyb@lyken.rs) for v0 support.
 
@@ -74,12 +74,6 @@ struct rust_demangler
   /* Rust mangling version, with legacy mangling being -1. */
   int version;
 
-  /* Recursion depth.  */
-  unsigned recursion;
-  /* Maximum number of times demangle_path may be called recursively.  */
-#define RUST_MAX_RECURSION_COUNT  1024
-#define RUST_NO_RECURSION_LIMIT   ((unsigned) -1)
-
   uint64_t bound_lifetime_depth;
 };
 
@@ -677,15 +671,6 @@ demangle_path (struct rust_demangler *rdm, int in_value)
   if (rdm->errored)
     return;
 
-  if (rdm->recursion != RUST_NO_RECURSION_LIMIT)
-    {
-      ++ rdm->recursion;
-      if (rdm->recursion > RUST_MAX_RECURSION_COUNT)
-	/* FIXME: There ought to be a way to report
-	   that the recursion limit has been reached.  */
-	goto fail_return;
-    }
-
   switch (tag = next (rdm))
     {
     case 'C':
@@ -703,7 +688,10 @@ demangle_path (struct rust_demangler *rdm, int in_value)
     case 'N':
       ns = next (rdm);
       if (!ISLOWER (ns) && !ISUPPER (ns))
-	goto fail_return;
+        {
+          rdm->errored = 1;
+          return;
+        }
 
       demangle_path (rdm, in_value);
 
@@ -788,15 +776,9 @@ demangle_path (struct rust_demangler *rdm, int in_value)
         }
       break;
     default:
-      goto fail_return;
+      rdm->errored = 1;
+      return;
     }
-  goto pass_return;
-
- fail_return:
-  rdm->errored = 1;
- pass_return:
-  if (rdm->recursion != RUST_NO_RECURSION_LIMIT)
-    -- rdm->recursion;
 }
 
 static void
@@ -1338,7 +1320,6 @@ rust_demangle_callback (const char *mangled, int options,
   rdm.skipping_printing = 0;
   rdm.verbose = (options & DMGL_VERBOSE) != 0;
   rdm.version = 0;
-  rdm.recursion = (options & DMGL_NO_RECURSE_LIMIT) ? RUST_NO_RECURSION_LIMIT : 0;
   rdm.bound_lifetime_depth = 0;
 
   /* Rust symbols always start with _R (v0) or _ZN (legacy). */
