@@ -126,44 +126,42 @@ do_proto_toplev()
 	    fi
 	else
 	    if (echo x$d | grep / >/dev/null); then
-	      mkdir -p proto-toplev/`dirname $d`
-	      x=`dirname $d`
-	      ln -s ../`echo $x/ | sed -e 's,[^/]*/,../,g'`$d proto-toplev/$d
+		mkdir -p proto-toplev/`dirname $d`
+		x=`dirname $d`
+		ln -s ../`echo $x/ | sed -e 's,[^/]*/,../,g'`$d proto-toplev/$d
 	    else
-	      ln -s ../$d proto-toplev/$d
+		ln -s ../$d proto-toplev/$d
 	    fi
-	  fi
-	done
-	(cd etc; $MAKE MAKEINFOFLAGS="$MAKEINFOFLAGS" info)
-	$MAKE distclean
-	mkdir proto-toplev/etc
-	(cd proto-toplev/etc;
-	    for i in $ETC_SUPPORT; do
-		ln -s ../../etc/$i .
-		done)
-	#
-	# Take out texinfo from configurable dirs
-	rm proto-toplev/configure.ac
-	sed -e '/^host_tools=/s/texinfo //' \
-	    <configure.ac >proto-toplev/configure.ac
-	#
-	mkdir proto-toplev/texinfo
-	ln -s ../../texinfo/texinfo.tex	proto-toplev/texinfo/
-	if test -r texinfo/util/tex3patch ; then
-	    mkdir proto-toplev/texinfo/util && \
-		ln -s ../../../texinfo/util/tex3patch proto-toplev/texinfo/util
-	else
-	    true
 	fi
-	chmod -R og=u . || chmod og=u `find . -print`
-	#
-	# Create .gmo files from .po files.
-	for f in `find . -name '*.po' -type f -print`; do
-	    msgfmt -o `echo $f | sed -e 's/\.po$/.gmo/'` $f
-	done
-	#
-	rm -f $package-$ver
-	ln -s proto-toplev $package-$ver
+    done
+    (cd etc; $MAKE MAKEINFOFLAGS="$MAKEINFOFLAGS" info)
+    $MAKE distclean
+    mkdir proto-toplev/etc
+    (cd proto-toplev/etc;
+	for i in $ETC_SUPPORT; do
+	    ln -s ../../etc/$i .
+	done)
+    #
+    # Take out texinfo from configurable dirs
+    rm proto-toplev/configure.ac
+    sed -e '/^host_tools=/s/texinfo //' \
+	<configure.ac >proto-toplev/configure.ac
+    #
+    mkdir proto-toplev/texinfo
+    ln -s ../../texinfo/texinfo.tex proto-toplev/texinfo/
+    if test -r texinfo/util/tex3patch ; then
+	mkdir proto-toplev/texinfo/util && \
+	    ln -s ../../../texinfo/util/tex3patch proto-toplev/texinfo/util
+    fi
+    chmod -R og=u . || chmod og=u `find . -print`
+    #
+    # Create .gmo files from .po files.
+    for f in `find . -name '*.po' -type f -print`; do
+	msgfmt -o `echo $f | sed -e 's/\.po$/.gmo/'` $f
+    done
+    #
+    rm -f $package-$ver
+    ln -s proto-toplev $package-$ver
 }
 
 CVS_NAMES='-name CVS -o -name .cvsignore'
@@ -315,7 +313,7 @@ gas_release()
     tar_compress $package $tool "$GAS_SUPPORT_DIRS" "$compressors"
 }
 
-GDB_SUPPORT_DIRS="bfd include libiberty libctf opcodes readline sim intl libdecnumber cpu zlib contrib gnulib gdbsupport gdbserver"
+GDB_SUPPORT_DIRS="bfd include libiberty libctf opcodes readline sim intl libdecnumber cpu zlib contrib gnulib gdbsupport gdbserver libbacktrace"
 gdb_release()
 {
     compressors=$1
